package org.apache.bcel.classfile;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;

/* loaded from: org_apache_bcel_classfile.jar:org/apache/bcel/classfile/LineNumber.class */
public final class LineNumber implements Cloneable, Node {
    private short startPc;
    private short lineNumber;

    /* JADX INFO: Access modifiers changed from: package-private */
    public LineNumber(DataInput file) throws IOException {
        this(file.readUnsignedShort(), file.readUnsignedShort());
    }

    public LineNumber(int startPc, int lineNumber) {
        this.startPc = (short) startPc;
        this.lineNumber = (short) lineNumber;
    }

    public LineNumber(LineNumber c) {
        this(c.getStartPC(), c.getLineNumber());
    }

    @Override // org.apache.bcel.classfile.Node
    public void accept(Visitor v) {
        v.visitLineNumber(this);
    }

    public LineNumber copy() {
        try {
            return (LineNumber) clone();
        } catch (CloneNotSupportedException e) {
            return null;
        }
    }

    public void dump(DataOutputStream file) throws IOException {
        file.writeShort(this.startPc);
        file.writeShort(this.lineNumber);
    }

    public int getLineNumber() {
        return this.lineNumber & 65535;
    }

    public int getStartPC() {
        return this.startPc & 65535;
    }

    public void setLineNumber(int lineNumber) {
        this.lineNumber = (short) lineNumber;
    }

    public void setStartPC(int startPc) {
        this.startPc = (short) startPc;
    }

    public String toString() {
        return "LineNumber(" + getStartPC() + ", " + getLineNumber() + ")";
    }
}
